==> ejc-proequipmentcorp-impl-3.0.0-20221017.101726-8-sources.jar: com/ejianc/business/proequipmentcorppur/purchaseplan/bean/PurchasePlanDetailedEntity.java <==
package com.ejianc.business.proequipmentcorppur.purchaseplan.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 采购计划-计划清单表
 *
 * @author generator
 *
 */
@TableName("ejc_proequipmentcorp_purchase_plan_detailed")
public class PurchasePlanDetailedEntity extends BaseEntity {

    private static final long serialVersionUID = -7018484654437355028L;

    @TableField(value="code")
    private String code; // 序号
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="company")
    private String company; // 单位
    @TableField(value="plan_num")
    private Long planNum; // 计划数量
    @TableField(value="estimate_price")
    private BigDecimal estimatePrice; // 预计单价
    @TableField(value="estimate_amount")
    private BigDecimal estimateAmount; // 预计金额
    @TableField(value="estimate_purchase_date")
    private Date estimatePurchaseDate; // 预计采购时间
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_type")
    private String sourceType; // 来源类型
    @TableField(value="plan_id")
    private Long planId; // 所属计划Id(计划表主键相当于pid)
    @TableField(value="doc_category_id")
    private Long docCategoryId; // 档案分类id
    @TableField(value="doc_id")
    private Long docId; // 档案Id
    @TableField(value="tid")
    private Long tid; // 上级id
    @TableField(value="parent_id")
    private Long parentId; // 父类id
    @TableField(value="leaf_flag")
    private Boolean leafFlag; //
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码

    @TableField(value = "current_inventory")
    private BigDecimal currentInventory; //当前库存

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }
    public Long getPlanNum() {
        return planNum;
    }

    public void setPlanNum(Long planNum) {
        this.planNum = planNum;
    }
    public BigDecimal getEstimatePrice() {
        return estimatePrice;
    }

    public void setEstimatePrice(BigDecimal estimatePrice) {
        this.estimatePrice = estimatePrice;
    }
    public BigDecimal getEstimateAmount() {
        return estimateAmount;
    }

    public void setEstimateAmount(BigDecimal estimateAmount) {
        this.estimateAmount = estimateAmount;
    }
    public Date getEstimatePurchaseDate() {
        return estimatePurchaseDate;
    }

    public void setEstimatePurchaseDate(Date estimatePurchaseDate) {
        this.estimatePurchaseDate = estimatePurchaseDate;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getDocCategoryId() {
        return docCategoryId;
    }

    public void setDocCategoryId(Long docCategoryId) {
        this.docCategoryId = docCategoryId;
    }
    public Long getDocId() {
        return docId;
    }

    public void setDocId(Long docId) {
        this.docId = docId;
    }
    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public BigDecimal getCurrentInventory() {
        return currentInventory;
    }

    public void setCurrentInventory(BigDecimal currentInventory) {
        this.currentInventory = currentInventory;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20221220.151353-256-sources.jar: com/ejianc/business/proequipmentcorppur/purchaseplan/bean/PurchasePlanDetailedEntity.java <==
package com.ejianc.business.proequipmentcorppur.purchaseplan.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 采购计划-计划清单表
 *
 * @author generator
 *
 */
@TableName("ejc_proequipmentcorp_purchase_plan_detailed")
public class PurchasePlanDetailedEntity extends BaseEntity {

    private static final long serialVersionUID = -7018484654437355028L;

    @TableField(value="code")
    private String code; // 序号
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="company")
    private String company; // 单位
    @TableField(value="plan_num")
    private Long planNum; // 计划数量
    @TableField(value="estimate_price")
    private BigDecimal estimatePrice; // 预计单价
    @TableField(value="estimate_amount")
    private BigDecimal estimateAmount; // 预计金额
    @TableField(value="estimate_purchase_date")
    private Date estimatePurchaseDate; // 预计采购时间
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_type")
    private String sourceType; // 来源类型
    @TableField(value="plan_id")
    private Long planId; // 所属计划Id(计划表主键相当于pid)
    @TableField(value = "plan_code")
    private String planCode; //计划编码
    @TableField(value="doc_category_id")
    private Long docCategoryId; // 档案分类id
    @TableField(value="doc_id")
    private Long docId; // 档案Id
    @TableField(value="tid")
    private Long tid; // 上级id
    @TableField(value="parent_id")
    private Long parentId; // 父类id
    @TableField(value="leaf_flag")
    private Boolean leafFlag; //
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码

    @TableField(value = "current_inventory")
    private Long currentInventory; //当前库存

    @TableField(value = "applied_num")
    private Long appliedNum; //已申请数量
    @TableField(value = "remaining_num")
    private Long remainingNum; // 剩余可申请数量


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }
    public Long getPlanNum() {
        return planNum;
    }

    public void setPlanNum(Long planNum) {
        this.planNum = planNum;
    }
    public BigDecimal getEstimatePrice() {
        return estimatePrice;
    }

    public void setEstimatePrice(BigDecimal estimatePrice) {
        this.estimatePrice = estimatePrice;
    }
    public BigDecimal getEstimateAmount() {
        return estimateAmount;
    }

    public void setEstimateAmount(BigDecimal estimateAmount) {
        this.estimateAmount = estimateAmount;
    }
    public Date getEstimatePurchaseDate() {
        return estimatePurchaseDate;
    }

    public void setEstimatePurchaseDate(Date estimatePurchaseDate) {
        this.estimatePurchaseDate = estimatePurchaseDate;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getDocCategoryId() {
        return docCategoryId;
    }

    public void setDocCategoryId(Long docCategoryId) {
        this.docCategoryId = docCategoryId;
    }
    public Long getDocId() {
        return docId;
    }

    public void setDocId(Long docId) {
        this.docId = docId;
    }
    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public Long getCurrentInventory() {
        return currentInventory;
    }

    public void setCurrentInventory(Long currentInventory) {
        this.currentInventory = currentInventory;
    }

    public Long getAppliedNum() {
        return appliedNum;
    }

    public void setAppliedNum(Long appliedNum) {
        this.appliedNum = appliedNum;
    }

    public String getPlanCode() {
        return planCode;
    }

    public void setPlanCode(String planCode) {
        this.planCode = planCode;
    }

    public Long getRemainingNum() {
        return remainingNum;
    }

    public void setRemainingNum(Long remainingNum) {
        this.remainingNum = remainingNum;
    }
}
